========================
GEDCOM parser for Python
========================


.. image:: https://img.shields.io/pypi/v/ged4py.svg
        :target: https://pypi.python.org/pypi/ged4py

.. image:: https://img.shields.io/travis/andy-z/ged4py.svg
        :target: https://travis-ci.org/andy-z/ged4py

.. image:: https://readthedocs.org/projects/ged4py/badge/?version=latest
        :target: https://ged4py.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Implementation of the GEDCOM parser in Python


* Free software: MIT license
* Documentation: https://ged4py.readthedocs.io.


Features
--------

* Parsing of GEDCOM files as defined by 5.5.1 version of GEDCOM standard
* Supported file encodings are UTF-8 (with or without BOM), ASCII or ANSEL
* Designed to parse large files efficiently
* Supports Python 2.7 and 3.3+

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
